@@ -144,7 +144,7 @@ sjt.corr <- function(data,
   # try to automatically set labels is not passed as argument
   # --------------------------------------------------------
   if (is.null(var.labels) && is.data.frame(data)) {
-    var.labels <- sjmisc::get_label(data, def.value = colnames(data))
+    var.labels <- sjlabelled::get_label(data, def.value = colnames(data))
   }
   # ----------------------------
   # check for valid argument
