@@ -14,7 +14,7 @@
 #' @param pred.labels Character vector with labels of predictor variables.
 #'          If not \code{NULL}, \code{pred.labels} will be used in the first
 #'          table column with the predictors' names. If \code{NULL}, variable
-#'          labels are set based on label attributes (see \code{\link[sjmisc]{get_label}}).
+#'          labels are set based on label attributes (see \code{\link[sjlabelled]{get_label}}).
 #'          If \code{pred.labels = ""}, column names (vector names) are used
 #'          as predictor labels. See 'Examples'.
 #' @param depvar.labels Character vector with labels of dependent
@@ -390,7 +390,7 @@ sjt.lm <- function(...,
   # -----------------------------------------------------------
   # check argument. No model-summary supported for plm-objects
   # -----------------------------------------------------------
-  if (any(class(input_list[[1]]) == "plm")) {
+  if (inherits(input_list[[1]], "plm")) {
     # -----------------------------------------------------------
     # check package availability if fit is plm-object
     # -----------------------------------------------------------
@@ -1345,7 +1345,7 @@ sjt.lm <- function(...,
 #' efc$grp = as.factor(efc$e15relat)
 #' levels(x = efc$grp) <- get_labels(efc$e15relat)
 #' efc$care.level <- sjmisc::rec(efc$n4pstu,
-#'                               recodes = "0=0;1=1;2=2;3:4=3",
+#'                               rec = "0=0;1=1;2=2;3:4=3",
 #'                               as.num = FALSE)
 #' levels(x = efc$care.level) <- c("none", "I", "II", "III")
 #'
