@@ -16,8 +16,8 @@
 #' @param data A data frame that should be used to compute a PCA, or a \code{\link{prcomp}} object.
 #' @param rotation Rotation of the factor loadings. May be \code{"varimax"} for orthogonal rotation
 #'          or \code{"oblimin"} for oblique transformation.
-#' @param nmbr.fctr Number of factors used for calculating the varimax
-#'          rotation. By default, this value is \code{NULL} and the amount of factors is
+#' @param nmbr.fctr Number of factors used for calculating the rotation. By
+#'          default, this value is \code{NULL} and the amount of factors is
 #'          calculated according to the Kaiser-criteria.
 #' @param fctr.load.tlrn Specifies the minimum difference a variable needs to have between
 #'          factor loadings (components) in order to indicate a clear loading on just one factor and not
@@ -28,7 +28,7 @@
 #' @param show.cronb Logical, if \code{TRUE} (default), the cronbach's alpha value for each factor scale will be calculated,
 #'          i.e. all variables with the highest loading for a factor are taken for the
 #'          reliability test. The result is an alpha value for each factor dimension.
-#'          Only applies when \code{data} is a data frame and no \code{\link{prcomp}} object.
+#'          Only applies when \code{data} is a data frame.
 #' @param show.msa Logical, if \code{TRUE}, shows an additional column with the measure of sampling adequacy according
 #'          dor each component.
 #' @param show.var Logical, if \code{TRUE}, the proportions of variances for each component as well as cumulative
@@ -71,7 +71,7 @@
 #' # recveive last item of COPE-index scale
 #' end <- which(colnames(efc) == "c90cop9")
 #' # auto-detection of labels
-#' sjt.pca(efc[, c(start:end)])}
+#' sjt.pca(efc[, start:end])}
 #'
 #' @importFrom psych KMO
 #' @importFrom stats prcomp
@@ -105,7 +105,7 @@ sjt.pca <- function(data,
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
   if (is.null(var.labels) && is.data.frame(data)) {
-    var.labels <- sjmisc::get_label(data, def.value = colnames(data))
+    var.labels <- sjlabelled::get_label(data, def.value = colnames(data))
   }
   # ----------------------------
   # check if user has passed a data frame
